Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(68)

Unified Diff: webrtc/logging/rtc_event_log/rtc_event_log_parser.h

Issue 2851303007: Replace AudioReceiveStream::Config with rtclog::StreamConfig. (Closed)
Patch Set: Rebased. Created 3 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: webrtc/logging/rtc_event_log/rtc_event_log_parser.h
diff --git a/webrtc/logging/rtc_event_log/rtc_event_log_parser.h b/webrtc/logging/rtc_event_log/rtc_event_log_parser.h
index befc619cb17285b90b5d8282ea64b3b2e241f177..d5aee967667e3abbbc426b5999cd6371dc8d4629 100644
--- a/webrtc/logging/rtc_event_log/rtc_event_log_parser.h
+++ b/webrtc/logging/rtc_event_log/rtc_event_log_parser.h
@@ -122,10 +122,9 @@ class ParsedRtcEventLog {
// Only the fields that are stored in the protobuf will be written.
void GetVideoSendConfig(size_t index, rtclog::StreamConfig* config) const;
// Reads a config event to a (non-NULL) AudioReceiveStream::Config struct.
// Only the fields that are stored in the protobuf will be written.
- void GetAudioReceiveConfig(size_t index,
- AudioReceiveStream::Config* config) const;
+ void GetAudioReceiveConfig(size_t index, rtclog::StreamConfig* config) const;
// Reads a config event to a (non-NULL) AudioSendStream::Config struct.
// Only the fields that are stored in the protobuf will be written.
« no previous file with comments | « webrtc/logging/rtc_event_log/rtc_event_log2text.cc ('k') | webrtc/logging/rtc_event_log/rtc_event_log_parser.cc » ('j') | no next file with comments »
@@ -122,10 +122,9 @@ class ParsedRtcEventLog {
// Only the fields that are stored in the protobuf will be written.
void GetVideoSendConfig(size_t index, rtclog::StreamConfig* config) const;
- // Reads a config event to a (non-NULL) AudioReceiveStream::Config struct.
+ // Reads a config event to a (non-NULL) StreamConfig struct.
// Only the fields that are stored in the protobuf will be written.

Powered by Google App Engine
This is Rietveld 408576698